package com.ruoyi.project.sems.mapper;

import java.util.List;

import com.ruoyi.project.sems.domain.TSpecdevYlgd;

/**
 * 特种设备压力管道台账Mapper接口
 *
 * @author ruoyi
 * @date 2021-07-22
 */
public interface TSpecdevYlgdMapper{
    /**
     * 查询特种设备压力管道台账
     *
     * @param id 特种设备压力管道台账ID
     * @return 特种设备压力管道台账
     */
    public TSpecdevYlgd selectTSpecdevYlgdById(Long id);

    /**
     * 查询特种设备压力管道台账
     *
     * @param ids 特种设备压力管道台账ID集合
     * @return 特种设备压力管道台账
     */
    public List<TSpecdevYlgd> selectTSpecdevYlgdByIds(List<Long> ids);

    /**
     * 查询特种设备压力管道台账列表
     *
     * @param tSpecdevYlgd 特种设备压力管道台账
     * @return 特种设备压力管道台账集合
     */
//    @DataScopePlant(deptAlias = "d")
    public List<TSpecdevYlgd> selectTSpecdevYlgdList(TSpecdevYlgd tSpecdevYlgd);

    List<TSpecdevYlgd> selectTSpecdevYlgdListByYear(TSpecdevYlgd tSpecdevYlgd);
    /**
     * 新增特种设备压力管道台账
     *
     * @param tSpecdevYlgd 特种设备压力管道台账
     * @return 结果
     */
    public int insertTSpecdevYlgd(TSpecdevYlgd tSpecdevYlgd);

    /**
     * 修改特种设备压力管道台账
     *
     * @param tSpecdevYlgd 特种设备压力管道台账
     * @return 结果
     */
    public int updateTSpecdevYlgd(TSpecdevYlgd tSpecdevYlgd);

    /**
     * 删除特种设备压力管道台账
     *
     * @param id 特种设备压力管道台账ID
     * @return 结果
     */
    public int deleteTSpecdevYlgdById(Long id);

    /**
     * 批量删除特种设备压力管道台账
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSpecdevYlgdByIds(Long[] ids);

    void duplicateTSpecdevYlgd();
}
